import { Controller, Get, Post, Body, Patch, Param, Delete, UseGuards } from "@nestjs/common";
import { JudgementsService } from './judgements.service';
import { AddedJudgementDto } from './dto/added-judgement.dto';
import { UpdateJudgementDto } from './dto/update-judgement.dto';
import {
  AddedNewJudgementResponseType,
  GetListJudgementsResponseType,
  GetOneJudgementResponseType,
  UpdateJudgementResponse,
  RemoveJudgementResponse,
  GetPaginatedListOfJudgementsResponse
} from "../types";
import { AuthGuard } from "@nestjs/passport";
import { UserObj } from "../decorators/user-obj.decorator";
import { User } from "../user/entities/user.entity";

@Controller('/judgements')
export class JudgementsController {
  constructor(private readonly judgementsService: JudgementsService) {}

  @Post('/')
  @UseGuards(AuthGuard('jwt'))
  addJudgement(
    @Body() newJudgement: AddedJudgementDto,
    @UserObj() user: User,
  ): Promise<AddedNewJudgementResponseType> {
    return this.judgementsService.addJudgement(newJudgement, user);
  }

  @Get('/')
  showAllJudgements(): Promise<GetListJudgementsResponseType> {
    return this.judgementsService.showAllJudgements();
  }

  @Get('/:id')
  showOneJudgements(@Param('id') id: string): Promise<GetOneJudgementResponseType> {
    return this.judgementsService.showOneJudgements(id);
  }

  @Get('/page/:pageNumber')
  showNineJudgementsPerPage(@Param('pageNumber') pageNumber: string): Promise<GetPaginatedListOfJudgementsResponse> {
    return this.judgementsService.showNineJudgementsPerPage(Number(pageNumber));
  }

  @Patch('/:id')
  @UseGuards(AuthGuard('jwt'))
  updateOneJudgement(
    @Param('id') id: string,
    @Body() updateJudgementDto: UpdateJudgementDto,
    @UserObj() user: User,
  ): Promise<UpdateJudgementResponse> {
    return this.judgementsService.updateOneJudgement(id, updateJudgementDto, user);
  }

  @Delete('/:id')
  @UseGuards(AuthGuard('jwt'))
  removeOneJudgement(@Param('id') id: string): Promise<RemoveJudgementResponse> {
    return this.judgementsService.removeOneJudgement(id);
  }
}
